@@ -12,7 +12,7 @@ import inspect
 from pathlib import Path, PurePath
 import json
 import types
-
+import copy
 
 
 
@@ -255,6 +255,32 @@ s os only within the "Process"-function.
             raise TypeError('Def is not a dict')
         self.__IsPrepared = False   # we need a Prepare-call after this 
 
+    @property
+    def Definition(self):
+        return copy.deepcopy(self.__Definition)
+
+    def GetCmdPar(self, Entry: str) -> str:
+        Erg = ""
+        try:
+            SingleDef = self.__Definition[Entry]
+        except:
+            return ''
+        try:
+            wText = SingleDef[self.__WorkPars['shortpar']]
+            for w in wText:
+                Erg += "-" + w + " "
+        except:
+            pass
+        try:
+            wText = SingleDef[self.__WorkPars['longpar']]
+            if type(wText) == list or type(wText) == tuple:
+                for w in wText:
+                    Erg += "--" + w + " "
+            elif type(wText) == str:
+                Erg += "--" + wText + " "
+        except: 
+            pass
+        return Erg
 
     def SetUserKeys(self, UserPars: dict = None, UserModes: dict = None) -> None:
         """
@@ -1169,5 +1195,7 @@ if __name__ == "__main__":
         # print(dir(a))
         print(f"Ergebnis: {a}")
         print(f"Rest: {a.GetRemainder()}")
+        print(a.GetCmdPar('Text'))
+        print(a.Definition)
         # print(a.Usage())
     main()
